PortError

Enum PortError 

pub enum PortError {
    Empty,
    InvalidPort,
    InvalidPortNumber(u32),
    Undelimited,
    Unknown(ErrorKind),
}
An error encountered when parsing an invalid port field in a pgpass file.

Variants



Empty

The supplied port was empty. This is invalid; use the wildcard character *.



InvalidPort

The port number could not be parsed (eg it contained characters other than digits, or was > u32::MAX).



InvalidPortNumber(u32)

The number supplied was not a valid port number. Valid port numbers are in the range 1..=65535.



Undelimited

An unanticipated error from nom. This should not happen. If you observe this error, it is a bug. The field was not followed by it’s delimiter



Unknown(ErrorKind)